@@ -119,10 +119,14 @@ QWidget* WidgetFactory::createWidget(const QString& prop, const QVariant& value,
         // vHanda: FIXME: Add links! Take m_noLinks into consideration
         QString valueString;
 
-        if (prop == QStringLiteral("duration")) {
+        if (prop == QLatin1String("duration")) {
             valueString = form.formatDuration(value.toInt() * 1000);
-        } else if (prop == QStringLiteral("bitRate")) {
-            valueString = i18nc("@label bitrate (per second)", "%1/s", form.formatByteSize(value.toInt(), 1, KFormat::MetricBinaryDialect));
+        } else if (prop == QLatin1String("bitRate")) {
+            valueString = i18nc("@label bitrate (per second)", "%1/s", form.formatByteSize(value.toInt(), 0, KFormat::MetricBinaryDialect));
+        } else if (prop == QLatin1String("sampleRate")) {
+            valueString = i18nc("@label samplerate in kilohertz", "%1 kHz", QLocale().toString(value.toDouble() / 1000));
+        } else if (prop == QLatin1String("releaseYear")) {
+            valueString = value.toString();
         } else if (prop == QLatin1String("originUrl")) {
             if (m_noLinks) {
                 valueString = value.toString();
@@ -150,7 +154,7 @@ QWidget* WidgetFactory::createWidget(const QString& prop, const QVariant& value,
 
     widget->setForegroundRole(parent->foregroundRole());
     widget->setFont(parent->font());
-
+    widget->setObjectName(prop);
     return widget;
 }
 
@@ -210,7 +214,7 @@ class ValueWidget : public QLabel
 {
 public:
     explicit ValueWidget(QWidget* parent = 0);
-    virtual QSize sizeHint() const;
+    virtual QSize sizeHint() const Q_DECL_OVERRIDE;
 };
 
 ValueWidget::ValueWidget(QWidget* parent) :
